## 股票技术因子（量化因子）

接口：stk_factor

描述：获取股票每日技术面因子数据，用于跟踪股票当前走势情况，数据由Tushare社区自产，覆盖全历史

限量：单次最大10000条，可以循环或者分页提取

积分：5000积分每分钟可以请求100次，8000积分以上每分钟500次，具体请参阅积分获取办法 

```python
注：
1、本接口的前复权行情是从最新一个交易日开始往前复权，是历史当日的数据快照数据不更新
2、pro_bar接口的前复权是动态复权，即以end_date参数开始往前复权，与本接口会存在不一致的可能
3、本接口技术指标都是基于前复权价格计算
```

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期 （yyyymmdd，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_date | str | Y | 交易日期 |
| close | float | Y | 收盘价 |
| open | float | Y | 开盘价 |
| high | float | Y | 最高价 |
| low | float | Y | 最低价 |
| pre_close | float | Y | 昨收价 |
| change | float | Y | 涨跌额 |
| pct_change | float | Y | 涨跌幅 |
| vol | float | Y | 成交量 （手） |
| amount | float | Y | 成交额 （千元） |
| adj_factor | float | Y | 复权因子 |
| open_hfq | float | Y | 开盘价后复权 |
| open_qfq | float | Y | 开盘价前复权 |
| close_hfq | float | Y | 收盘价后复权 |
| close_qfq | float | Y | 收盘价前复权 |
| high_hfq | float | Y | 最高价后复权 |
| high_qfq | float | Y | 最高价前复权 |
| low_hfq | float | Y | 最低价后复权 |
| low_qfq | float | Y | 最低价前复权 |
| pre_close_hfq | float | Y | 昨收价后复权 |
| pre_close_qfq | float | Y | 昨收价前复权 |
| macd_dif | float | Y | MCAD_DIF (基于前复权价格计算，下同) |
| macd_dea | float | Y | MCAD_DEA |
| macd | float | Y | MCAD |
| kdj_k | float | Y | KDJ_K |
| kdj_d | float | Y | KDJ_D |
| kdj_j | float | Y | KDJ_J |
| rsi_6 | float | Y | RSI_6 |
| rsi_12 | float | Y | RSI_12 |
| rsi_24 | float | Y | RSI_24 |
| boll_upper | float | Y | BOLL_UPPER |
| boll_mid | float | Y | BOLL_MID |
| boll_lower | float | Y | BOLL_LOWER |
| cci | float | Y | CCI |

接口用法

```python
pro = ts.pro_api()

df = pro.stk_factor(ts_code='600000.SH', start_date='20220501', end_date='20220520', fields='ts_code,trade_date,macd,kdj_k,kdj_d,kdj_j')
```

数据样例

```python
ts_code trade_date   macd   kdj_k   kdj_d   kdj_j
0   600000.SH   20220520   0.027  72.966  64.718   89.46
```